==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/SectionInformationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionInformationDescription } from "./SectionInformationDescription";
/**
 * @hidden
 */
export let SectionInformationDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionInformationDescriptionMetadata extends Base {
        static b(a) {
            if (SectionInformationDescriptionMetadata.a == null) {
                SectionInformationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionInformationDescriptionMetadata.c(SectionInformationDescriptionMetadata.a);
            }
            if (a.k(SectionInformationDescriptionMetadata.a)) {
                return;
            }
            a.ab(SectionInformationDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            SectionInformationDescriptionMetadata.b(a);
            a.ad("SectionInformation", () => new SectionInformationDescription());
            a.ac("SectionInformation", SectionInformationDescriptionMetadata.a);
        }
    }
    SectionInformationDescriptionMetadata.$t = /*@__PURE__*/ markType(SectionInformationDescriptionMetadata, 'SectionInformationDescriptionMetadata');
    SectionInformationDescriptionMetadata.a = null;
    return SectionInformationDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/SectionInformationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionInformationDescription } from "./SectionInformationDescription";
/**
 * @hidden
 */
export let SectionInformationDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionInformationDescriptionMetadata extends Base {
        static b(a) {
            if (SectionInformationDescriptionMetadata.a == null) {
                SectionInformationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionInformationDescriptionMetadata.c(SectionInformationDescriptionMetadata.a);
            }
            if (a.k(SectionInformationDescriptionMetadata.a)) {
                return;
            }
            a.ac(SectionInformationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
        }
        static d(a) {
            SectionInformationDescriptionMetadata.b(a);
            a.ae("SectionInformation", () => new SectionInformationDescription());
            a.ad("SectionInformation", SectionInformationDescriptionMetadata.a);
        }
    }
    SectionInformationDescriptionMetadata.$t = /*@__PURE__*/ markType(SectionInformationDescriptionMetadata, 'SectionInformationDescriptionMetadata');
    SectionInformationDescriptionMetadata.a = null;
    return SectionInformationDescriptionMetadata;
})();
